import os
import openai
import json
import LibHanger.Library.uwLogger as Logger

class opaipyBase():
    
    """
    opaipyBase
    """
    
    class aiLang():
        
        """
        言語設定
        """
        
        jp = 'Jp'
        """ 日本語 """

        en = 'En'
        """ 英語 """

    def __init__(self, _rootPath, _organization, _api_key, _jsonFilePath) -> None:
        
        """
        コンストラクタ
        
        Parameters
        ----------
        _organization : str
            organization
        _api_key : str
            api_key
        """

        # 認証情報
        openai.organization = _organization
        openai.api_key = _api_key

        # ルートパス
        self.rootPathFull = _rootPath
        self.rootPath = os.path.dirname(_rootPath)

        # openai - response
        self.response = None

        # PromptJsonFile Path
        self.jsonFilePath = _jsonFilePath
    
    @property
    def responseMessage(self):
        
        """
        OpenAIからの返答
        """
        return self.response['choices'][0]['message']['content']
    
    def request(self, _jsonFileName):
        
        """
        openAIから返答を取得する

        Parameters
        ----------
        _jsonFileName : str
            プロンプトのjsonファイル名
        """

        # ファイル名
        jsonFilePath = os.path.join(
            os.path.dirname(self.rootPath), 
            self.jsonFilePath,
            _jsonFileName)
        
        # jsonファイルチェック
        if not os.path.exists(jsonFilePath):
            Logger.logging.info('jsonfile is not found.')
            return

        # jsonファイルOpen
        with open(jsonFilePath, encoding="utf-8") as f:
            prompt = json.loads(f.read())

        # openaiの返答を取得する
        self.response = openai.ChatCompletion.create(
            model= prompt['model'],
            messages=[
                {"role": "system", "content": prompt['systemContent']},
                {"role": "user", "content": '\n'.join(prompt['userContent'])},
                #{"role": "assistant", "content": "補足説明を記載（使わなくてもOK）"},
            ],)
    


from LibHanger.Library.uwGlobals import globalValues
from opaipy.Library.opaipyConfig import opaipyConfig

class opaipyGlobal(globalValues):
    
    def __init__(self):
        
        """
        コンストラクタ
        """
        
        # 基底側コンストラクタ呼び出し
        super().__init__()

        self.opaipyConfig:opaipyConfig = None
        """ opaipy共通設定 """

# インスタンス生成(import時に実行される)
gvOna = opaipyGlobal()



import LibHanger.Library.uwLogger as Logger
from LibHanger.Library.uwGlobals import configer
from LibHanger.Library.uwGlobals import *
from opaipy.Library.opaipyGlobals import *

class opaipyConfiger(configer):
    
    """
    opaipy共通設定クラス
    """
    
    def __init__(self, _tgv:opaipyGlobal, _file, _configFolderName = ''):
        
        """
        コンストラクタ
        """
        
        # opaipy.ini
        da = opaipyConfig()
        da.getConfig(_file, _configFolderName)

        # gvセット
        _tgv.opaipyConfig = da
        
        # ロガー設定
        Logger.setting(da)



from enum import Enum
from LibHanger.Library.uwConfig import cmnConfig

class opaipyConfig(cmnConfig):
    
    """
    opaipy共通設定クラス(opaipyConfig)
    """ 
    
    class settingValueStruct(cmnConfig.settingValueStruct):

        """
        設定値構造体
        """ 

        pass
            
    def __init__(self):
        
        """
        コンストラクタ
        """
        
        # 基底側コンストラクタ
        super().__init__()
        
        self.organization = ''
        """ organization """
        
        self.api_key = ''
        """ api_key """
        
        self.jsonFilePath = ''
        """ PromptJsonFile Path """
        
        # 設定ファイル名追加
        self.setConfigFileName('opaipy.ini')
        
    def getConfig(self, _scriptFilePath: str, configFileDir: str = ''):
        
        """ 
        設定ファイルを読み込む 
        
        Parameters
        ----------
        _scriptFilePath : str
            スクリプトファイルパス
        configFileDir : str
            設定ファイルの格納場所となるディレクトリ
        """

        # 基底側のiniファイル読込
        super().getConfig(_scriptFilePath, configFileDir)
        
    def setInstanceMemberValues(self):
        
        """ 
        インスタンス変数に読み取った設定値をセットする
        """
        
        # 基底側実行
        super().setInstanceMemberValues()
        
        # organization
        self.setConfigValue('organization',self.config_ini,'AUTH','ORGANIZATION',str)

        # api_key
        self.setConfigValue('api_key',self.config_ini,'AUTH','API_KEY',str)

        # PromptJsonFile Path
        self.setConfigValue('jsonFilePath',self.config_ini,'DIR','PROMPT_JSON_PATH',str)
